######################################
 Support class for HP legacy devices 
######################################

Currently this implementation is used for the following instruments which do not support SCPI:

* HP3437A System-Voltmeter

* HP3478A Digital Multimeter

* HP6632/33/34A System power supply

.. autoclass:: pymeasure.instruments.hp.HPLegacyInstrument
    :members:
    :show-inheritance:
